@@ -11,13 +11,18 @@
 #' used in endpoints such as best overall response.
 #'
 #' @param dataset
+#'
 #'   `r roxygen_param_dataset(expected_vars = c("by_vars", "join_vars"))`
 #'
+#' @permitted [dataset]
+#'
 #' @param dataset_add Additional dataset
 #'
 #'   The variables specified for `by_vars`, `join_vars`, and `order` are
 #'   expected.
 #'
+#' @permitted [dataset]
+#'
 #' @param by_vars Grouping variables
 #'
 #'   The specified variables are used for joining the input
@@ -25,25 +30,38 @@
 #'
 #'   `r roxygen_param_by_vars()`
 #'
+#' @permitted [var_list]
+#'
 #' @param order Order
 #'
-#'   The observations are ordered by the specified order.
+#'   The observations are ordered by the specified order if `join_type =
+#'   "after"`, `join_type = "before"`, `first_cond_lower`, `first_cond_upper`,
+#'   or `tmp_obs_nr_var` are specified.
 #'
 #'   `r roxygen_order_na_handling()`
 #'
+#' @permitted [var_list]
+#'
 #' @param new_var New variable
 #'
 #'   The specified variable is added to the input dataset.
 #'
+#' @permitted [var]
+#'
 #' @param tmp_obs_nr_var Temporary observation number
 #'
 #'   The specified variable is added to the input dataset (`dataset`) and the
 #'   additional dataset (`dataset_add`). It is set to the observation number
 #'   with respect to `order`. For each by group (`by_vars`) the observation
-#'   number starts with `1`. The variable can be used in the conditions
-#'   (`filter_join`, `first_cond_upper`, `first_cond_lower`). It is not included
-#'   in the output dataset. It can also be used to flag consecutive observations
-#'   or the last observation (see last example below).
+#'   number starts with `1`. If there is more than one record for specific
+#'   values for `by_vars` and `order`, all records get the same observation
+#'   number. By default, a warning (see `check_type`) is issued in this case.
+#'   The variable can be used in the conditions (`filter_join`,
+#'   `first_cond_upper`, `first_cond_lower`). It is not included in the output
+#'   dataset. It can also be used to flag consecutive observations or the last
+#'   observation (see last example below).
+#'
+#' @permitted [var]
 #'
 #' @param join_vars Variables to keep from joined dataset
 #'
@@ -56,6 +74,8 @@
 #'
 #'   The `*.join` variables are not included in the output dataset.
 #'
+#' @permitted [var_list]
+#'
 #' @param first_cond_lower Condition for selecting range of data (before)
 #'
 #'   If this argument is specified, the other observations are restricted from
@@ -69,6 +89,8 @@
 #'   certain observation before the current observation up to the current
 #'   observation. For an example see the last example below.
 #'
+#' @permitted [condition]
+#'
 #' @param first_cond_upper Condition for selecting range of data (after)
 #'
 #'   If this argument is specified, the other observations are restricted up to
@@ -80,6 +102,8 @@
 #'   functions which should not apply to all observations but only up to the
 #'   confirmation assessment. For an example see the third example below.
 #'
+#' @permitted [condition]
+#'
 #' @param filter_join Condition for selecting observations
 #'
 #'   The filter is applied to the joined dataset for flagging the confirmed
@@ -92,18 +116,24 @@
 #'   confirmation observation the response is "CR" or "NE" and there is at most
 #'   one "NE".
 #'
+#' @permitted [condition]
+#'
 #' @param check_type Check uniqueness?
 #'
-#'   If `"warning"` or `"error"` is specified, the specified message is issued
-#'   if the observations of the input dataset are not unique with respect to the
-#'   by variables and the order.
+#'   If `"message"`, `"warning"`, or `"error"` is specified, the specified
+#'   message is issued if the observations of the input dataset are not unique
+#'   with respect to the by variables and the order.
 #'
-#'   *Permitted Values:* `"none"`, `"warning"`, `"error"`
+#' @permitted [msg_type]
 #'
 #' @param true_value Value of `new_var` for flagged observations
 #'
+#' @permitted [char_scalar]
+#'
 #' @param false_value Value of `new_var` for observations not flagged
 #'
+#' @permitted [char_scalar]
+#'
 #' @inheritParams get_joined_data
 #'
 #' @details
@@ -178,7 +208,7 @@
 #'   fulfilling the condition is included). If for an observation of the input
 #'   dataset the condition is not fulfilled, the observation is removed.
 #'
-#'   For an example see the last example in the "Examples" section.
+#'   For examples see the "Examples" section.
 #'
 #'   ## Step 4
 #'
@@ -188,7 +218,7 @@
 #'
 #'   ## Step 5
 #'
-#'   The first observation of each group is selected
+#'   The first observation of each group is selected.
 #'
 #'   ## Step 6
 #'
@@ -207,11 +237,19 @@
 #'
 #' @export
 #'
-#' @examples
+#' @examplesx
+#' @caption Flag records considering other records (`filter_join`, `join_vars`)
+#' @info In this example, records with a duration longer than 30 and where a
+#'   COVID AE (`ACOVFL == "Y"`) occurred before or up to seven days after the
+#'   record should be flagged. The condition for flagging the records is
+#'   specified by the `filter_join` argument. Variables from the other records
+#'   are referenced by variable names with the suffix `.join`. These variables
+#'   have to be specified for the `join_vars` argument. As records before _and_
+#'   after the current record should be considered, `join_type = "all"` is
+#'   specified.
+#' @code
 #' library(tibble)
 #'
-#' # flag observations with a duration longer than 30 and
-#' # at, after, or up to 7 days before a COVID AE (ACOVFL == "Y")
 #' adae <- tribble(
 #'   ~USUBJID, ~ADY, ~ACOVFL, ~ADURN,
 #'   "1",        10, "N",          1,
@@ -233,11 +271,20 @@
 #'   by_vars = exprs(USUBJID),
 #'   join_vars = exprs(ACOVFL, ADY),
 #'   join_type = "all",
-#'   order = exprs(ADY),
-#'   filter_join = ADURN > 30 & ACOVFL.join == "Y" & ADY >= ADY.join - 7
+#'   filter_join = ADURN > 30 & ACOVFL.join == "Y" & ADY.join <= ADY + 7
 #' )
 #'
-#' # flag observations with AVALC == "Y" and AVALC == "Y" at one subsequent visit
+#' @caption Considering only records after the current one (`join_type =
+#'   "after"`, `true_value`, `false_value`)
+#' @info In this example, records with `AVALC == "Y"` and `AVALC == "Y"` at a
+#'   subsequent visit should be flagged. `join_type = "after"` is specified to
+#'   consider only records after the current one. Please note that the `order`
+#'   argument must be specified, as otherwise it is not possible to determine
+#'   which records are after the current record.
+#'
+#'   Please note that a numeric flag is created here by specifying the
+#'   `true_value` and the `false_value` argument.
+#' @code
 #' data <- tribble(
 #'   ~USUBJID, ~AVISITN, ~AVALC,
 #'   "1",      1,        "Y",
@@ -255,15 +302,79 @@
 #'   data,
 #'   dataset_add = data,
 #'   by_vars = exprs(USUBJID),
-#'   new_var = CONFFL,
+#'   new_var = CONFFLN,
 #'   join_vars = exprs(AVALC, AVISITN),
 #'   join_type = "after",
 #'   order = exprs(AVISITN),
-#'   filter_join = AVALC == "Y" & AVALC.join == "Y" & AVISITN < AVISITN.join
+#'   filter_join = AVALC == "Y" & AVALC.join == "Y",
+#'   true_value = 1,
+#'   false_value = 0
 #' )
 #'
-#' # select observations with AVALC == "CR", AVALC == "CR" at a subsequent visit,
-#' # only "CR" or "NE" in between, and at most one "NE" in between
+#' @caption Considering a range of records only (`first_cond_lower`, `first_cond_upper`)
+#' @info Consider the following data.
+#' @code
+#' myd <- tribble(
+#'   ~subj, ~day, ~val,
+#'   "1",      1, "++",
+#'   "1",      2, "-",
+#'   "1",      3, "0",
+#'   "1",      4, "+",
+#'   "1",      5, "++",
+#'   "1",      6, "-",
+#'   "2",      1, "-",
+#'   "2",      2, "++",
+#'   "2",      3, "+",
+#'   "2",      4, "0",
+#'   "2",      5, "-",
+#'   "2",      6, "++"
+#' )
+#'
+#' @info To flag `"0"` where all results from the first `"++"` before the `"0"`
+#' up to the `"0"` (excluding the `"0"`) are `"+"` or `"++"` the
+#' `first_cond_lower` argument and `join_type = "before"` are specified.
+#' @code
+#' derive_var_joined_exist_flag(
+#'   myd,
+#'   dataset_add = myd,
+#'   by_vars = exprs(subj),
+#'   order = exprs(day),
+#'   new_var = flag,
+#'   join_vars = exprs(val),
+#'   join_type = "before",
+#'   first_cond_lower = val.join == "++",
+#'   filter_join = val == "0" & all(val.join %in% c("+", "++"))
+#' )
+#'
+#' @info To flag `"0"` where all results from the `"0"` (excluding the `"0"`) up
+#' to the first `"++"` after the `"0"` are `"+"` or `"++"` the
+#' `first_cond_upper` argument and `join_type = "after"` are specified.
+#' @code
+#' derive_var_joined_exist_flag(
+#'   myd,
+#'   dataset_add = myd,
+#'   by_vars = exprs(subj),
+#'   order = exprs(day),
+#'   new_var = flag,
+#'   join_vars = exprs(val),
+#'   join_type = "after",
+#'   first_cond_upper = val.join == "++",
+#'   filter_join = val == "0" & all(val.join %in% c("+", "++"))
+#' )
+#'
+#' @caption Considering only records up to a condition (`first_cond_upper`)
+#' @info In this example from deriving confirmed response in oncology, the
+#'   records with
+#' - `AVALC == "CR"`,
+#' - `AVALC == "CR"` at a subsequent visit,
+#' - only `"CR"` or `"NE"` in between, and
+#' - at most one `"NE"` in between
+#'
+#' should be flagged. The other records to be considered are restricted to those
+#' up to the first occurrence of `"CR"` by specifying the `first_cond_upper`
+#' argument. The `count_vals()` function is used to count the `"NE"`s for the
+#' last condition.
+#' @code
 #' data <- tribble(
 #'   ~USUBJID, ~AVISITN, ~AVALC,
 #'   "1",      1,        "PR",
@@ -295,9 +406,22 @@
 #'     count_vals(var = AVALC.join, val = "NE") <= 1
 #' )
 #'
-#' # flag observations with AVALC == "PR", AVALC == "CR" or AVALC == "PR"
-#' # at a subsequent visit at least 20 days later, only "CR", "PR", or "NE"
-#' # in between, at most one "NE" in between, and "CR" is not followed by "PR"
+#' @caption Considering order of values (`min_cond()`, `max_cond()`)
+#' @info In this example from deriving confirmed response in oncology, records
+#'   with
+#' - `AVALC == "PR"`,
+#' - `AVALC == "CR"` or `AVALC == "PR"` at a subsequent visit at least 20 days later,
+#' - only `"CR"`, `"PR"`, or `"NE"` in between,
+#' - at most one `"NE"` in between, and
+#' - `"CR"` is
+#'   not followed by `"PR"`
+#'
+#' should be flagged. The last condition is realized by using `min_cond()` and
+#' `max_cond()`, ensuring that the first occurrence of `"CR"` is after the last
+#' occurrence of `"PR"`. The second call to `count_vals()` in the condition is
+#' required to cover the case of no `"CR"`s (the `min_cond()` call returns `NA`
+#' then).
+#' @code
 #' data <- tribble(
 #'   ~USUBJID, ~ADY, ~AVALC,
 #'   "1",         6, "PR",
@@ -335,7 +459,13 @@
 #'     )
 #' )
 #'
-#' # flag observations with CRIT1FL == "Y" at two consecutive visits or at the last visit
+#' @caption Considering the order of records (`tmp_obs_nr_var`)
+#' @info In this example, the records with `CRIT1FL == "Y"` at two consecutive
+#'   visits or at the last visit should be flagged. A temporary order variable
+#'   is created by specifying the `tmp_obs_nr_var` argument. Then it is used in
+#'   `filter_join`. The temporary variable doesn't need to be specified for
+#'   `join_vars`.
+#' @code
 #' data <- tribble(
 #'   ~USUBJID, ~AVISITN, ~CRIT1FL,
 #'   "1",      1,        "Y",
@@ -363,61 +493,18 @@
 #'     (tmp_obs_nr + 1 == tmp_obs_nr.join | tmp_obs_nr == max(tmp_obs_nr.join))
 #' )
 #'
-#' # first_cond_lower and first_cond_upper argument
-#' myd <- tribble(
-#'   ~subj, ~day, ~val,
-#'   "1",      1, "++",
-#'   "1",      2, "-",
-#'   "1",      3, "0",
-#'   "1",      4, "+",
-#'   "1",      5, "++",
-#'   "1",      6, "-",
-#'   "2",      1, "-",
-#'   "2",      2, "++",
-#'   "2",      3, "+",
-#'   "2",      4, "0",
-#'   "2",      5, "-",
-#'   "2",      6, "++"
-#' )
-#'
-#' # flag "0" where all results from the first "++" before the "0" up to the "0"
-#' # (excluding the "0") are "+" or "++"
-#' derive_var_joined_exist_flag(
-#'   myd,
-#'   dataset_add = myd,
-#'   by_vars = exprs(subj),
-#'   order = exprs(day),
-#'   new_var = flag,
-#'   join_vars = exprs(val),
-#'   join_type = "before",
-#'   first_cond_lower = val.join == "++",
-#'   filter_join = val == "0" & all(val.join %in% c("+", "++"))
-#' )
-#'
-#' # flag "0" where all results from the "0" (excluding the "0") up to the first
-#' # "++" after the "0" are "+" or "++"
-#' derive_var_joined_exist_flag(
-#'   myd,
-#'   dataset_add = myd,
-#'   by_vars = exprs(subj),
-#'   order = exprs(day),
-#'   new_var = flag,
-#'   join_vars = exprs(val),
-#'   join_type = "after",
-#'   first_cond_upper = val.join == "++",
-#'   filter_join = val == "0" & all(val.join %in% c("+", "++"))
-#' )
-#'
-#' # flag each dose which is lower than the previous dose per subject
+#' @caption Flag each dose which is lower than the previous dose
+#'   (`tmp_obs_nr_var`)
+#' @code
 #' ex <- tribble(
-#'   ~USUBJID, ~EXSTDTM,          ~EXDOSE,
-#'   "1",      "2024-01-01T08:00",      2,
-#'   "1",      "2024-01-02T08:00",      4,
-#'   "2",      "2024-01-01T08:30",      1,
-#'   "2",      "2024-01-02T08:30",      4,
-#'   "2",      "2024-01-03T08:30",      3,
-#'   "2",      "2024-01-04T08:30",      2,
-#'   "2",      "2024-01-05T08:30",      2
+#'   ~USUBJID, ~EXSTDTM,           ~EXDOSE,
+#'   "1",      "2024-01-01T08:00",       2,
+#'   "1",      "2024-01-02T08:00",       4,
+#'   "2",      "2024-01-01T08:30",       1,
+#'   "2",      "2024-01-02T08:30",       4,
+#'   "2",      "2024-01-03T08:30",       3,
+#'   "2",      "2024-01-04T08:30",       2,
+#'   "2",      "2024-01-05T08:30",       2
 #' )
 #'
 #' derive_var_joined_exist_flag(
@@ -436,8 +523,12 @@
 #'   )
 #' )
 #'
-#' # derive definitive deterioration flag as any deterioration (CHGCAT1 = "Worsened")
-#' # by parameter that is not followed by a non-deterioration
+#' @caption Derive definitive deterioration flag
+#' @info In this example a definitive deterioration flag should be derived as
+#'   any deterioration (`CHGCAT1 = "Worsened"`) by parameter that is not
+#'   followed by a non-deterioration. Please note that `join_type = "after"`
+#'   can't by used here, as otherwise the last record wouldn't be flagged.
+#' @code
 #' adqs <- tribble(
 #'   ~USUBJID, ~PARAMCD, ~ADY, ~CHGCAT1,
 #'   "1",      "QS1",      10, "Improved",
@@ -454,15 +545,63 @@
 #'   dataset_add = adqs,
 #'   new_var = DDETERFL,
 #'   by_vars = exprs(USUBJID, PARAMCD),
-#'   join_vars = exprs(CHGCAT1),
+#'   join_vars = exprs(CHGCAT1, ADY),
 #'   join_type = "all",
-#'   order = exprs(ADY),
 #'   filter_join = all(CHGCAT1.join == "Worsened" | ADY > ADY.join)
 #' )
+#'
+#' @caption Handling duplicates (`check_type`)
+#' @info If the `order` argument is used, it is checked if the records are
+#'   unique with respect to `by_vars` and `order`. Consider for example the
+#'   derivation of `CONFFL` which flags records with `AVALC == "Y"` which are
+#'   confirmed at a subsequent visit.
+#' @code [expected_cnds = "duplicate_records"]
+#' data <- tribble(
+#'   ~USUBJID, ~AVISITN, ~ADY, ~AVALC,
+#'   "1",      1,           1, "Y",
+#'   "1",      2,           8, "N",
+#'   "1",      3,          15, "Y",
+#'   "1",      4,          22, "N",
+#'   "2",      1,           1, "Y",
+#'   "2",      2,           8, "Y",
+#'   "2",      2,          10, "Y"
+#' )
+#'
+#' derive_var_joined_exist_flag(
+#'   data,
+#'   dataset_add = data,
+#'   by_vars = exprs(USUBJID),
+#'   new_var = CONFFL,
+#'   join_vars = exprs(AVALC, AVISITN),
+#'   join_type = "after",
+#'   order = exprs(AVISITN),
+#'   filter_join = AVALC == "Y" & AVALC.join == "Y"
+#' )
+#' @info The records for `USUBJID == "2"` are not unique with respect to
+#'   `USUBJID` and `AVISITN`. Thus a warning is issued. The duplicates can be
+#'   accessed by calling `get_duplicates_dataset()`:
+#' @code
+#' get_duplicates_dataset()
+#' @info In this example, confirmation is required at a subsequent _visit_.
+#'   Please note that the first record for subject `"2"` at visit `2` is not
+#'   flagged. Thus the warning can be suppressed by specifying `check_type =
+#'   "none"`.
+#' @code
+#' derive_var_joined_exist_flag(
+#'   data,
+#'   dataset_add = data,
+#'   by_vars = exprs(USUBJID),
+#'   new_var = CONFFL,
+#'   join_vars = exprs(AVALC, AVISITN),
+#'   join_type = "after",
+#'   order = exprs(AVISITN),
+#'   filter_join = AVALC == "Y" & AVALC.join == "Y",
+#'   check_type = "none"
+#' )
 derive_var_joined_exist_flag <- function(dataset,
                                          dataset_add,
                                          by_vars,
-                                         order,
+                                         order = NULL,
                                          new_var,
                                          tmp_obs_nr_var = NULL,
                                          join_vars,
