@@ -73,7 +73,9 @@ test_that("compute_egfr Test 7: CKD-EPI calculated on input data", {
     "P01", "P01-1001", 55, "M", "WHITE", 90.7, 96.3, "umol/L",
     "P01", "P01-1002", 52, "F", "BLACK OR AFRICAN AMERICAN", 68, 70, "umol/L",
     "P01", "P01-1003", 67, "M", "BLACK OR AFRICAN AMERICAN", 85, 77, "umol/L",
-    "P01", "P01-1004", 76, "F", "ASIAN", 60, 65, "umol/L"
+    "P01", "P01-1004", 76, "F", "ASIAN", 60, 65, "umol/L",
+    "P01", "P01-1005", 54, NA_character_, "AMERICAN INDIAN OR ALASKA NATIVE", 65, 68,
+    "umol/L",
   )
 
   expected_output <- tibble::tribble(
@@ -82,6 +84,8 @@ test_that("compute_egfr Test 7: CKD-EPI calculated on input data", {
     "P01", "P01-1002", 52, "F", "BLACK OR AFRICAN AMERICAN", 68, 70, "umol/L", 89.7175,
     "P01", "P01-1003", 67, "M", "BLACK OR AFRICAN AMERICAN", 85, 77, "umol/L", 94.5453,
     "P01", "P01-1004", 76, "F", "ASIAN", 60, 65, "umol/L", 84.4646,
+    "P01", "P01-1005", 54, NA_character_, "AMERICAN INDIAN OR ALASKA NATIVE", 65, 68,
+    "umol/L", NA_real_,
   )
 
   egfr <- input %>%
